@@ -4,11 +4,6 @@
 
 #filter substitution
 
-# LOCALIZATION NOTE: this preference is set to true for en-US specifically,
-# locales without this line have the setting set to false by default.
-pref("browser.search.geoSpecificDefaults", true);
-
-
 #ifdef XP_WIN
 
 // overwrite zh-CN defaults with zh-TW ones in win32 Firefox. (see bug 603549)
